@@ -1,5 +1,5 @@
 import requests
-import url
+from aybrequests.url_utils import urljoiner
 
 class AYBRequest():
 
@@ -10,30 +10,30 @@ class AYBRequest():
         self.prefix_url = prefix_url
 
     def get(self,url, params=None, **kwargs):
-        return requests.get(url.urljoiner(self.prefix_url,url), params=params, **kwargs)
+        return requests.get(urljoiner(self.prefix_url,url), params=params, **kwargs)
 
 
     def options(self,url, **kwargs):
-        return requests.options(url.urljoiner(self.prefix_url,url), **kwargs)
+        return requests.options(urljoiner(self.prefix_url,url), **kwargs)
 
 
     def head(self,url, **kwargs):
         kwargs.setdefault('allow_redirects', False)
-        return requests.head(url.urljoiner(self.prefix_url,url), **kwargs)
+        return requests.head(urljoiner(self.prefix_url,url), **kwargs)
 
 
     def post(self,url, data=None, json=None, **kwargs):
-        return requests.post(url.urljoiner(self.prefix_url,url), data=data, json=json, **kwargs)
+        return requests.post(urljoiner(self.prefix_url,url), data=data, json=json, **kwargs)
 
 
     def put(self,url, data=None, **kwargs):
-        return requests.put(url.urljoiner(self.prefix_url,url), data=data, **kwargs)
+        return requests.put(urljoiner(self.prefix_url,url), data=data, **kwargs)
 
 
     def patch(self,url, data=None, **kwargs):
-        return requests.patch(url.urljoiner(self.prefix_url,url), data=data, **kwargs)
+        return requests.patch(urljoiner(self.prefix_url,url), data=data, **kwargs)
 
 
     def delete(self,url, **kwargs):
-        return requests.delete(url.urljoiner(self.prefix_url,url), **kwargs)
+        return requests.delete(urljoiner(self.prefix_url,url), **kwargs)
     
\ No newline at end of file
